# ape.types

## Miscellaneous

```{eval-rst}
.. automodule:: ape.types
    :members: BlockID, AddressType, BaseContractLog, ContractLog, MockContractLog
```

## Signatures

```{eval-rst}
.. automodule:: ape.types.signatures
    :members:
    :show-inheritance:
```
